@@ -100,6 +100,7 @@ static pfmlib_pmu_t *pfmlib_pmus[]=
 	&intel_hsw_support,
 	&intel_hsw_ep_support,
 	&intel_bdw_support,
+	&intel_bdw_ep_support,
 	&intel_skl_support,
 	&intel_rapl_support,
 	&intel_snbep_unc_cb0_support,
@@ -124,6 +125,7 @@ static pfmlib_pmu_t *pfmlib_pmus[]=
 	&intel_snbep_unc_r3qpi1_support,
 	&intel_knc_support,
 	&intel_slm_support,
+	&intel_glm_support,
 	&intel_ivbep_unc_cb0_support,
 	&intel_ivbep_unc_cb1_support,
 	&intel_ivbep_unc_cb2_support,
@@ -200,6 +202,7 @@ static pfmlib_pmu_t *pfmlib_pmus[]=
 	&intel_hswep_unc_r3qpi1_support,
 	&intel_hswep_unc_r3qpi2_support,
 	&intel_hswep_unc_irp_support,
+	&intel_knl_support,
 	&intel_x86_arch_support, /* must always be last for x86 */
 #endif
 
@@ -674,6 +677,9 @@ pfmlib_match_forced_pmu(const char *name)
 static int
 pfmlib_is_blacklisted_pmu(pfmlib_pmu_t *p)
 {
+	char *q, *buffer;
+	int ret = 1;
+
 	if (!pfm_cfg.blacklist_pmus)
 		return 0;
 
@@ -681,15 +687,20 @@ pfmlib_is_blacklisted_pmu(pfmlib_pmu_t *p)
 	 * scan list for matching PMU names, we accept substrings.
 	 * for instance: snbep does match snbep*
 	 */
-	char *q, buffer[strlen(pfm_cfg.blacklist_pmus) + 1];
+	buffer = strdup(pfm_cfg.blacklist_pmus);
+	if (!buffer)
+		return 0;
 
 	strcpy (buffer, pfm_cfg.blacklist_pmus);
 	for (q = strtok (buffer, ","); q != NULL; q = strtok (NULL, ",")) {
 		if (strstr (p->name, q) != NULL) {
-			return 1;
+			goto done;
 		}
 	}
-	return 0;
+	ret = 0;
+done:
+	free(buffer);
+	return ret;
 }
 
 static int
@@ -903,9 +914,10 @@ pfmlib_parse_event_attr(char *str, pfmlib_event_desc_t *d)
 	s = str;
 
 	while(s) {
-		p = strchr(s, PFMLIB_ATTR_DELIM);
-		if (p)
-			*p++ = '\0';
+	        p = s;
+	        strsep(&p, PFMLIB_ATTR_DELIM);
+		/* if (p)
+		 *p++ = '\0'; */
 
 		q = strchr(s, '=');
 		if (q)
@@ -936,10 +948,10 @@ pfmlib_parse_event_attr(char *str, pfmlib_event_desc_t *d)
 			ainfo->name = "RAW_UMASK";
 			ainfo->type = PFM_ATTR_RAW_UMASK;
 			ainfo->ctrl = PFM_ATTR_CTRL_PMU;
-			ainfo->idx  = strtoul(s, &endptr, 0);
+			ainfo->idx  = strtoull(s, &endptr, 0);
 			ainfo->equiv= NULL;
 			if (*endptr) {
-				DPRINT("raw umask (%s) is not a number\n");
+				DPRINT("raw umask (%s) is not a number\n", s);
 				return PFM_ERR_ATTR;
 			}
 
@@ -1149,9 +1161,10 @@ pfmlib_parse_equiv_event(const char *event, pfmlib_event_desc_t *d)
 	if (!str)
 		return PFM_ERR_NOMEM;
 
-	p = strchr(s, PFMLIB_ATTR_DELIM);
-	if (p)
-		*p++ = '\0';
+	p = s;
+	strsep(&p, PFMLIB_ATTR_DELIM);
+	/* if (p)
+	 *p++ = '\0'; */
 
 	match = pmu->match_event ? pmu->match_event : match_event;
 
@@ -1224,9 +1237,11 @@ pfmlib_parse_event(const char *event, pfmlib_event_desc_t *d)
 		pname = s;
 		s = p + strlen(PFMLIB_PMU_DELIM);
 	}
-	p = strchr(s, PFMLIB_ATTR_DELIM);
-	if (p)
-		*p++ = '\0';
+	p = s;
+	strsep(&p, PFMLIB_ATTR_DELIM);
+	/* if (p)
+	 *p++ = '\0'; */
+
 	/*
 	 * for each pmu
 	 */
@@ -1290,9 +1305,9 @@ found:
 	for (i = 0; i < d->nattrs; i++) {
 		pfm_event_attr_info_t *a = attr(d, i);
 		if (a->type != PFM_ATTR_RAW_UMASK)
-			DPRINT("%d %d %d %s\n", d->event, i, a->idx, d->pattrs[d->attrs[i].id].name);
+			DPRINT("%d %d %"PRIu64" %s\n", d->event, i, a->idx, d->pattrs[d->attrs[i].id].name);
 		else
-			DPRINT("%d %d RAW_UMASK (0x%x)\n", d->event, i, a->idx);
+			DPRINT("%d %d RAW_UMASK (0x%"PRIx64")\n", d->event, i, a->idx);
 	}
 error:
 	free(str);
