@@ -22,6 +22,8 @@
 #ifndef _PAPI
 #define _PAPI
 
+#pragma GCC visibility push(default)
+
 /**
  * @mainpage PAPI
  *  
@@ -219,7 +221,7 @@
 
 /* This is the official PAPI version */
 /* The final digit represents the patch count */
-#define PAPI_VERSION  			PAPI_VERSION_NUMBER(5,4,3,0)
+#define PAPI_VERSION  			PAPI_VERSION_NUMBER(5,5,0,0)
 #define PAPI_VER_CURRENT 		(PAPI_VERSION & 0xffff0000)
 
   /* Tests for checking event code type */
@@ -562,10 +564,11 @@ read the documentation carefully.  */
   typedef void (*PAPI_overflow_handler_t) (int EventSet, void *address,
                                 long long overflow_vector, void *context);
 
-        /* Handle C99 compilation */
-	/* All caddr_ts should become unsigned longs eventually. */
+        /* Handle C99 and more recent compilation */
+	/* caddr_t was never approved by POSIX and is obsolete */
+	/* We should probably switch all caddr_t to void * or long */
 #ifdef __STDC_VERSION__
-  #if (__STDC_VERSION__ == 199901L)
+  #if (__STDC_VERSION__ >= 199901L)
 	typedef char *caddr_t;
   #else
 
@@ -1132,4 +1135,7 @@ int   PAPI_num_hwctrs(void); /**< return the number of hardware counters for the
 #ifdef __cplusplus
 }
 #endif
+
+#pragma GCC visibility pop
+
 #endif
